/* main.h
 * Copyright (C) 2007-2008 Gauvain Pocentek <gpocentek@linutop.com>
 * This file is part of the linutop config editor
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 2 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#ifndef __MAIN_H__
#define __MAIN_H__

#include <libxklavier/xklavier.h>
#include <libxfcegui4/libxfcegui4.h>

#define README "/cdrom/readme.txt"

enum combo_enum
{
  DESC = 0,
  NOM,
  COMBO_NUM
};

enum tree_enum
{
  LAYOUTS = 0,
  VARIANTS,
  TREE_NUM
};

enum enumeration
{
  AVAIL_LAYOUT_TREE_COL_DESCRIPTION = 0,
  AVAIL_LAYOUT_TREE_COL_ID,
  NUM
};

enum tz
{
  AFRICA = 0,
  AMERICA,
  US,
  CANADA,
  ASIA,
  ATLANTIC,
  AUSTRALIA,
  EUROPE,
  INDIAN,
  PACIFIC,
  SYSV,
  ETC,
  NONE,
  CONTINENTS
};

const gchar *conf_file;

typedef struct _gui
{
  GtkWidget *dialog;

  GtkWidget *locale_entry;
  GtkWidget *locale_btn;
  GtkWidget *kbd_entry;
  GtkWidget *kbd_btn;
  GtkWidget *tz_entry;
  GtkWidget *tz_btn;
  GtkWidget *screen_combo;
  GtkWidget *net_btn;
  GtkWidget *next_time;

  GtkWidget *nox_chk;
  GtkWidget *checkfs_chk;
  GtkWidget *home_chk;
  GtkWidget *full_chk;

  GtkWidget *lock_chk;
  GtkWidget *lock_pwd_btn;
  GtkWidget *vbox_lock;

  gchar *tz_txt;
  gchar *locale_txt;
  gchar *kbd_txt[3];		/* 0->layout, 1->variant, 2->all */
  gchar *kbd_code_txt;
  gchar *orig_kbd;
  gchar *screen_txt;
  gchar *persistent;
  gchar *lock_pwd;
  gboolean lock;

  gchar *rootdevice;

  GtkWidget *text;

  GtkWidget *help_btn;
  GtkWidget *quit_btn;
  GtkWidget *save_btn;
} gui;

typedef struct _trees
{
  GtkWidget *treeview1;
  GtkWidget *treeview2;
  GtkTreeStore *treestore1;
  GtkTreeStore *treestore2;
} trees;

/* globals */
gui *dialog;
trees *alltrees;

Display *dsp;
XklEngine *engine;
XklConfigRegistry *registry;
XklConfigRec *user_rec_config;
GtkTreeIter iter, child;
GtkTreeModel *model;
GtkTreeSelection *selection;
GtkTreePath *path;

/* prototypes */
gchar *get_kbd_name (gchar * str);
gchar *get_locale_name (char *code);
gchar *layout_dialog_run (void);
gchar *locale_dialog_run (void);
gchar *tz_dialog_run (void);
void apply_kbd_config (gchar * kbd);
void mount_save ();
GtkWidget *create_mount_gui ();
gchar *get_lock_passwd ();
GtkWidget *lock_widget ();
gboolean warn_about_changes ();

#endif /* __MAIN_H__ */
